"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .collectionresponse import CollectionResponse, CollectionResponseTypedDict
from lambdadb.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListCollectionsResponseTypedDict(TypedDict):
    r"""A list of collections matched with a projectName."""

    collections: List[CollectionResponseTypedDict]


class ListCollectionsResponse(BaseModel):
    r"""A list of collections matched with a projectName."""

    collections: List[CollectionResponse]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .fieldsselector_union import FieldsSelectorUnion, FieldsSelectorUnionTypedDict
from .partitionfilter import PartitionFilter, PartitionFilterTypedDict
from lambdadb.types import BaseModel, UNSET_SENTINEL
from lambdadb.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from pydantic import model_serializer
from typing import Any, Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class QueryCollectionRequestBodyTypedDict(TypedDict):
    query: Dict[str, Any]
    r"""Query object."""
    size: NotRequired[int]
    r"""Number of documents to return. Note that the maximum number of documents is 100."""
    consistent_read: NotRequired[bool]
    r"""If your application requires a strongly consistent read, set consistentRead to true. Although a strongly consistent read might take more time than an eventually consistent read, it always returns the last updated value."""
    include_vectors: NotRequired[bool]
    r"""If your application need to include vector values in the response, set includeVectors to true."""
    sort: NotRequired[List[Dict[str, Any]]]
    r"""List of field name, sort direction pairs."""
    fields: NotRequired[FieldsSelectorUnionTypedDict]
    r"""An object to specify a list of field names to include and/or exclude in the result."""
    partition_filter: NotRequired[PartitionFilterTypedDict]


class QueryCollectionRequestBody(BaseModel):
    query: Dict[str, Any]
    r"""Query object."""

    size: Optional[int] = None
    r"""Number of documents to return. Note that the maximum number of documents is 100."""

    consistent_read: Annotated[
        Optional[bool], pydantic.Field(alias="consistentRead")
    ] = False
    r"""If your application requires a strongly consistent read, set consistentRead to true. Although a strongly consistent read might take more time than an eventually consistent read, it always returns the last updated value."""

    include_vectors: Annotated[
        Optional[bool], pydantic.Field(alias="includeVectors")
    ] = False
    r"""If your application need to include vector values in the response, set includeVectors to true."""

    sort: Optional[List[Dict[str, Any]]] = None
    r"""List of field name, sort direction pairs."""

    fields: Optional[FieldsSelectorUnion] = None
    r"""An object to specify a list of field names to include and/or exclude in the result."""

    partition_filter: Annotated[
        Optional[PartitionFilter], pydantic.Field(alias="partitionFilter")
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "size",
                "consistentRead",
                "includeVectors",
                "sort",
                "fields",
                "partitionFilter",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class QueryCollectionRequestTypedDict(TypedDict):
    collection_name: str
    r"""Collection name."""
    request_body: QueryCollectionRequestBodyTypedDict


class QueryCollectionRequest(BaseModel):
    collection_name: Annotated[
        str,
        pydantic.Field(alias="collectionName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Collection name."""

    request_body: Annotated[
        QueryCollectionRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class QueryCollectionDocTypedDict(TypedDict):
    collection: str
    r"""Collection name."""
    doc: Dict[str, Any]
    score: NotRequired[float]
    r"""Document similarity score."""


class QueryCollectionDoc(BaseModel):
    collection: str
    r"""Collection name."""

    doc: Dict[str, Any]

    score: Optional[float] = None
    r"""Document similarity score."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["score"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class QueryCollectionResponseTypedDict(TypedDict):
    r"""Documents selected by query."""

    took: int
    r"""Elapsed time in milliseconds."""
    total: int
    r"""Total number of documents returned."""
    docs: List[QueryCollectionDocTypedDict]
    r"""List of documents."""
    is_docs_inline: bool
    r"""Whether the list of documents is included."""
    max_score: NotRequired[float]
    r"""Maximum score."""
    docs_url: NotRequired[str]
    r"""Optional download URL for the list of documents."""


class QueryCollectionResponse(BaseModel):
    r"""Documents selected by query."""

    took: int
    r"""Elapsed time in milliseconds."""

    total: int
    r"""Total number of documents returned."""

    docs: List[QueryCollectionDoc]
    r"""List of documents."""

    is_docs_inline: Annotated[bool, pydantic.Field(alias="isDocsInline")]
    r"""Whether the list of documents is included."""

    max_score: Annotated[Optional[float], pydantic.Field(alias="maxScore")] = None
    r"""Maximum score."""

    docs_url: Annotated[Optional[str], pydantic.Field(alias="docsUrl")] = None
    r"""Optional download URL for the list of documents."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["maxScore", "docsUrl"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from lambdadb.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class PartitionFilterTypedDict(TypedDict):
    field: str
    r"""Partition field name."""
    in_: List[str]
    r"""Partition values to filter."""


class PartitionFilter(BaseModel):
    field: str
    r"""Partition field name."""

    in_: Annotated[List[str], pydantic.Field(alias="in")]
    r"""Partition values to filter."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .bulkupsertdocsop import (
        BulkUpsertDocsRequest,
        BulkUpsertDocsRequestBody,
        BulkUpsertDocsRequestBodyTypedDict,
        BulkUpsertDocsRequestTypedDict,
    )
    from .collectionresponse import CollectionResponse, CollectionResponseTypedDict
    from .createcollectionop import (
        CreateCollectionRequest,
        CreateCollectionRequestTypedDict,
        CreateCollectionResponse,
        CreateCollectionResponseTypedDict,
    )
    from .deletecollectionop import (
        DeleteCollectionRequest,
        DeleteCollectionRequestTypedDict,
    )
    from .deletedocsop import (
        DeleteDocsRequest,
        DeleteDocsRequestBody,
        DeleteDocsRequestBodyTypedDict,
        DeleteDocsRequestTypedDict,
    )
    from .fetchdocsop import (
        FetchDocsDoc,
        FetchDocsDocTypedDict,
        FetchDocsRequest,
        FetchDocsRequestBody,
        FetchDocsRequestBodyTypedDict,
        FetchDocsRequestTypedDict,
        FetchDocsResponse,
        FetchDocsResponseTypedDict,
    )
    from .fieldsselector_union import (
        FieldsSelector1,
        FieldsSelector1TypedDict,
        FieldsSelector2,
        FieldsSelector2TypedDict,
        FieldsSelectorUnion,
        FieldsSelectorUnionTypedDict,
    )
    from .getbulkupsertdocsop import (
        GetBulkUpsertDocsRequest,
        GetBulkUpsertDocsRequestTypedDict,
        GetBulkUpsertDocsResponse,
        GetBulkUpsertDocsResponseTypedDict,
        GetBulkUpsertDocsType,
        HTTPMethod,
    )
    from .getcollectionop import (
        GetCollectionRequest,
        GetCollectionRequestTypedDict,
        GetCollectionResponse,
        GetCollectionResponseTypedDict,
    )
    from .indexconfigs_union import (
        Analyzer,
        IndexConfigs,
        IndexConfigsObject,
        IndexConfigsObjectTypedDict,
        IndexConfigsText,
        IndexConfigsTextTypedDict,
        IndexConfigsTypedDict,
        IndexConfigsUnion,
        IndexConfigsUnionTypedDict,
        IndexConfigsVector,
        IndexConfigsVectorTypedDict,
        Similarity,
        Type,
        TypeObject,
        TypeText,
        TypeVector,
    )
    from .listcollectionsop import (
        ListCollectionsResponse,
        ListCollectionsResponseTypedDict,
    )
    from .listdocsop import (
        ListDocsRequest,
        ListDocsRequestTypedDict,
        ListDocsResponse,
        ListDocsResponseTypedDict,
    )
    from .messageresponse import MessageResponse, MessageResponseTypedDict
    from .partitionconfig import DataType, PartitionConfig, PartitionConfigTypedDict
    from .partitionfilter import PartitionFilter, PartitionFilterTypedDict
    from .querycollectionop import (
        QueryCollectionDoc,
        QueryCollectionDocTypedDict,
        QueryCollectionRequest,
        QueryCollectionRequestBody,
        QueryCollectionRequestBodyTypedDict,
        QueryCollectionRequestTypedDict,
        QueryCollectionResponse,
        QueryCollectionResponseTypedDict,
    )
    from .security import Security, SecurityTypedDict
    from .status import Status
    from .updatecollectionop import (
        UpdateCollectionRequest,
        UpdateCollectionRequestBody,
        UpdateCollectionRequestBodyTypedDict,
        UpdateCollectionRequestTypedDict,
        UpdateCollectionResponse,
        UpdateCollectionResponseTypedDict,
    )
    from .updatedocsop import (
        UpdateDocsRequest,
        UpdateDocsRequestBody,
        UpdateDocsRequestBodyTypedDict,
        UpdateDocsRequestTypedDict,
    )
    from .upsertdocsop import (
        UpsertDocsRequest,
        UpsertDocsRequestBody,
        UpsertDocsRequestBodyTypedDict,
        UpsertDocsRequestTypedDict,
    )

__all__ = [
    "Analyzer",
    "BulkUpsertDocsRequest",
    "BulkUpsertDocsRequestBody",
    "BulkUpsertDocsRequestBodyTypedDict",
    "BulkUpsertDocsRequestTypedDict",
    "CollectionResponse",
    "CollectionResponseTypedDict",
    "CreateCollectionRequest",
    "CreateCollectionRequestTypedDict",
    "CreateCollectionResponse",
    "CreateCollectionResponseTypedDict",
    "DataType",
    "DeleteCollectionRequest",
    "DeleteCollectionRequestTypedDict",
    "DeleteDocsRequest",
    "DeleteDocsRequestBody",
    "DeleteDocsRequestBodyTypedDict",
    "DeleteDocsRequestTypedDict",
    "FetchDocsDoc",
    "FetchDocsDocTypedDict",
    "FetchDocsRequest",
    "FetchDocsRequestBody",
    "FetchDocsRequestBodyTypedDict",
    "FetchDocsRequestTypedDict",
    "FetchDocsResponse",
    "FetchDocsResponseTypedDict",
    "FieldsSelector1",
    "FieldsSelector1TypedDict",
    "FieldsSelector2",
    "FieldsSelector2TypedDict",
    "FieldsSelectorUnion",
    "FieldsSelectorUnionTypedDict",
    "GetBulkUpsertDocsRequest",
    "GetBulkUpsertDocsRequestTypedDict",
    "GetBulkUpsertDocsResponse",
    "GetBulkUpsertDocsResponseTypedDict",
    "GetBulkUpsertDocsType",
    "GetCollectionRequest",
    "GetCollectionRequestTypedDict",
    "GetCollectionResponse",
    "GetCollectionResponseTypedDict",
    "HTTPMethod",
    "IndexConfigs",
    "IndexConfigsObject",
    "IndexConfigsObjectTypedDict",
    "IndexConfigsText",
    "IndexConfigsTextTypedDict",
    "IndexConfigsTypedDict",
    "IndexConfigsUnion",
    "IndexConfigsUnionTypedDict",
    "IndexConfigsVector",
    "IndexConfigsVectorTypedDict",
    "ListCollectionsResponse",
    "ListCollectionsResponseTypedDict",
    "ListDocsRequest",
    "ListDocsRequestTypedDict",
    "ListDocsResponse",
    "ListDocsResponseTypedDict",
    "MessageResponse",
    "MessageResponseTypedDict",
    "PartitionConfig",
    "PartitionConfigTypedDict",
    "PartitionFilter",
    "PartitionFilterTypedDict",
    "QueryCollectionDoc",
    "QueryCollectionDocTypedDict",
    "QueryCollectionRequest",
    "QueryCollectionRequestBody",
    "QueryCollectionRequestBodyTypedDict",
    "QueryCollectionRequestTypedDict",
    "QueryCollectionResponse",
    "QueryCollectionResponseTypedDict",
    "Security",
    "SecurityTypedDict",
    "Similarity",
    "Status",
    "Type",
    "TypeObject",
    "TypeText",
    "TypeVector",
    "UpdateCollectionRequest",
    "UpdateCollectionRequestBody",
    "UpdateCollectionRequestBodyTypedDict",
    "UpdateCollectionRequestTypedDict",
    "UpdateCollectionResponse",
    "UpdateCollectionResponseTypedDict",
    "UpdateDocsRequest",
    "UpdateDocsRequestBody",
    "UpdateDocsRequestBodyTypedDict",
    "UpdateDocsRequestTypedDict",
    "UpsertDocsRequest",
    "UpsertDocsRequestBody",
    "UpsertDocsRequestBodyTypedDict",
    "UpsertDocsRequestTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "BulkUpsertDocsRequest": ".bulkupsertdocsop",
    "BulkUpsertDocsRequestBody": ".bulkupsertdocsop",
    "BulkUpsertDocsRequestBodyTypedDict": ".bulkupsertdocsop",
    "BulkUpsertDocsRequestTypedDict": ".bulkupsertdocsop",
    "CollectionResponse": ".collectionresponse",
    "CollectionResponseTypedDict": ".collectionresponse",
    "CreateCollectionRequest": ".createcollectionop",
    "CreateCollectionRequestTypedDict": ".createcollectionop",
    "CreateCollectionResponse": ".createcollectionop",
    "CreateCollectionResponseTypedDict": ".createcollectionop",
    "DeleteCollectionRequest": ".deletecollectionop",
    "DeleteCollectionRequestTypedDict": ".deletecollectionop",
    "DeleteDocsRequest": ".deletedocsop",
    "DeleteDocsRequestBody": ".deletedocsop",
    "DeleteDocsRequestBodyTypedDict": ".deletedocsop",
    "DeleteDocsRequestTypedDict": ".deletedocsop",
    "FetchDocsDoc": ".fetchdocsop",
    "FetchDocsDocTypedDict": ".fetchdocsop",
    "FetchDocsRequest": ".fetchdocsop",
    "FetchDocsRequestBody": ".fetchdocsop",
    "FetchDocsRequestBodyTypedDict": ".fetchdocsop",
    "FetchDocsRequestTypedDict": ".fetchdocsop",
    "FetchDocsResponse": ".fetchdocsop",
    "FetchDocsResponseTypedDict": ".fetchdocsop",
    "FieldsSelector1": ".fieldsselector_union",
    "FieldsSelector1TypedDict": ".fieldsselector_union",
    "FieldsSelector2": ".fieldsselector_union",
    "FieldsSelector2TypedDict": ".fieldsselector_union",
    "FieldsSelectorUnion": ".fieldsselector_union",
    "FieldsSelectorUnionTypedDict": ".fieldsselector_union",
    "GetBulkUpsertDocsRequest": ".getbulkupsertdocsop",
    "GetBulkUpsertDocsRequestTypedDict": ".getbulkupsertdocsop",
    "GetBulkUpsertDocsResponse": ".getbulkupsertdocsop",
    "GetBulkUpsertDocsResponseTypedDict": ".getbulkupsertdocsop",
    "GetBulkUpsertDocsType": ".getbulkupsertdocsop",
    "HTTPMethod": ".getbulkupsertdocsop",
    "GetCollectionRequest": ".getcollectionop",
    "GetCollectionRequestTypedDict": ".getcollectionop",
    "GetCollectionResponse": ".getcollectionop",
    "GetCollectionResponseTypedDict": ".getcollectionop",
    "Analyzer": ".indexconfigs_union",
    "IndexConfigs": ".indexconfigs_union",
    "IndexConfigsObject": ".indexconfigs_union",
    "IndexConfigsObjectTypedDict": ".indexconfigs_union",
    "IndexConfigsText": ".indexconfigs_union",
    "IndexConfigsTextTypedDict": ".indexconfigs_union",
    "IndexConfigsTypedDict": ".indexconfigs_union",
    "IndexConfigsUnion": ".indexconfigs_union",
    "IndexConfigsUnionTypedDict": ".indexconfigs_union",
    "IndexConfigsVector": ".indexconfigs_union",
    "IndexConfigsVectorTypedDict": ".indexconfigs_union",
    "Similarity": ".indexconfigs_union",
    "Type": ".indexconfigs_union",
    "TypeObject": ".indexconfigs_union",
    "TypeText": ".indexconfigs_union",
    "TypeVector": ".indexconfigs_union",
    "ListCollectionsResponse": ".listcollectionsop",
    "ListCollectionsResponseTypedDict": ".listcollectionsop",
    "ListDocsRequest": ".listdocsop",
    "ListDocsRequestTypedDict": ".listdocsop",
    "ListDocsResponse": ".listdocsop",
    "ListDocsResponseTypedDict": ".listdocsop",
    "MessageResponse": ".messageresponse",
    "MessageResponseTypedDict": ".messageresponse",
    "DataType": ".partitionconfig",
    "PartitionConfig": ".partitionconfig",
    "PartitionConfigTypedDict": ".partitionconfig",
    "PartitionFilter": ".partitionfilter",
    "PartitionFilterTypedDict": ".partitionfilter",
    "QueryCollectionDoc": ".querycollectionop",
    "QueryCollectionDocTypedDict": ".querycollectionop",
    "QueryCollectionRequest": ".querycollectionop",
    "QueryCollectionRequestBody": ".querycollectionop",
    "QueryCollectionRequestBodyTypedDict": ".querycollectionop",
    "QueryCollectionRequestTypedDict": ".querycollectionop",
    "QueryCollectionResponse": ".querycollectionop",
    "QueryCollectionResponseTypedDict": ".querycollectionop",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "Status": ".status",
    "UpdateCollectionRequest": ".updatecollectionop",
    "UpdateCollectionRequestBody": ".updatecollectionop",
    "UpdateCollectionRequestBodyTypedDict": ".updatecollectionop",
    "UpdateCollectionRequestTypedDict": ".updatecollectionop",
    "UpdateCollectionResponse": ".updatecollectionop",
    "UpdateCollectionResponseTypedDict": ".updatecollectionop",
    "UpdateDocsRequest": ".updatedocsop",
    "UpdateDocsRequestBody": ".updatedocsop",
    "UpdateDocsRequestBodyTypedDict": ".updatedocsop",
    "UpdateDocsRequestTypedDict": ".updatedocsop",
    "UpsertDocsRequest": ".upsertdocsop",
    "UpsertDocsRequestBody": ".upsertdocsop",
    "UpsertDocsRequestBodyTypedDict": ".upsertdocsop",
    "UpsertDocsRequestTypedDict": ".upsertdocsop",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .indexconfigs_union import IndexConfigsUnion, IndexConfigsUnionTypedDict
from .partitionconfig import PartitionConfig, PartitionConfigTypedDict
from .status import Status
from lambdadb.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CollectionResponseTypedDict(TypedDict):
    project_name: str
    r"""Project name."""
    collection_name: str
    r"""Collection name."""
    index_configs: Dict[str, IndexConfigsUnionTypedDict]
    num_partitions: int
    r"""Total number of partitions including the default partition."""
    num_docs: int
    r"""Total number of documents."""
    collection_status: Status
    r"""Status"""
    partition_config: NotRequired[PartitionConfigTypedDict]
    source_project_name: NotRequired[str]
    r"""Source project name."""
    source_collection_name: NotRequired[str]
    r"""Source collection name."""
    source_collection_version_id: NotRequired[str]
    r"""Source collection version."""


class CollectionResponse(BaseModel):
    project_name: Annotated[str, pydantic.Field(alias="projectName")]
    r"""Project name."""

    collection_name: Annotated[str, pydantic.Field(alias="collectionName")]
    r"""Collection name."""

    index_configs: Annotated[
        Dict[str, IndexConfigsUnion], pydantic.Field(alias="indexConfigs")
    ]

    num_partitions: Annotated[int, pydantic.Field(alias="numPartitions")]
    r"""Total number of partitions including the default partition."""

    num_docs: Annotated[int, pydantic.Field(alias="numDocs")]
    r"""Total number of documents."""

    collection_status: Annotated[Status, pydantic.Field(alias="collectionStatus")]
    r"""Status"""

    partition_config: Annotated[
        Optional[PartitionConfig], pydantic.Field(alias="partitionConfig")
    ] = None

    source_project_name: Annotated[
        Optional[str], pydantic.Field(alias="sourceProjectName")
    ] = None
    r"""Source project name."""

    source_collection_name: Annotated[
        Optional[str], pydantic.Field(alias="sourceCollectionName")
    ] = None
    r"""Source collection name."""

    source_collection_version_id: Annotated[
        Optional[str], pydantic.Field(alias="sourceCollectionVersionId")
    ] = None
    r"""Source collection version."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "partitionConfig",
                "sourceProjectName",
                "sourceCollectionName",
                "sourceCollectionVersionId",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .fieldsselector_union import FieldsSelectorUnion, FieldsSelectorUnionTypedDict
from .partitionfilter import PartitionFilter, PartitionFilterTypedDict
from lambdadb.types import BaseModel, UNSET_SENTINEL
from lambdadb.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from pydantic import model_serializer
from typing import Any, Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class FetchDocsRequestBodyTypedDict(TypedDict):
    ids: List[str]
    r"""A list of document IDs to fetch. Note that the maximum number of document IDs is 100."""
    consistent_read: NotRequired[bool]
    r"""If your application requires a strongly consistent read, set consistentRead to true. Although a strongly consistent read might take more time than an eventually consistent read, it always returns the last updated value."""
    include_vectors: NotRequired[bool]
    r"""If your application need to include vector values in the response, set includeVectors to true."""
    fields: NotRequired[FieldsSelectorUnionTypedDict]
    r"""An object to specify a list of field names to include and/or exclude in the result."""
    partition_filter: NotRequired[PartitionFilterTypedDict]


class FetchDocsRequestBody(BaseModel):
    ids: List[str]
    r"""A list of document IDs to fetch. Note that the maximum number of document IDs is 100."""

    consistent_read: Annotated[
        Optional[bool], pydantic.Field(alias="consistentRead")
    ] = False
    r"""If your application requires a strongly consistent read, set consistentRead to true. Although a strongly consistent read might take more time than an eventually consistent read, it always returns the last updated value."""

    include_vectors: Annotated[
        Optional[bool], pydantic.Field(alias="includeVectors")
    ] = False
    r"""If your application need to include vector values in the response, set includeVectors to true."""

    fields: Optional[FieldsSelectorUnion] = None
    r"""An object to specify a list of field names to include and/or exclude in the result."""

    partition_filter: Annotated[
        Optional[PartitionFilter], pydantic.Field(alias="partitionFilter")
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["consistentRead", "includeVectors", "fields", "partitionFilter"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class FetchDocsRequestTypedDict(TypedDict):
    collection_name: str
    r"""Collection name."""
    request_body: FetchDocsRequestBodyTypedDict


class FetchDocsRequest(BaseModel):
    collection_name: Annotated[
        str,
        pydantic.Field(alias="collectionName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Collection name."""

    request_body: Annotated[
        FetchDocsRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class FetchDocsDocTypedDict(TypedDict):
    collection: str
    doc: Dict[str, Any]


class FetchDocsDoc(BaseModel):
    collection: str

    doc: Dict[str, Any]


class FetchDocsResponseTypedDict(TypedDict):
    r"""Fetched documents."""

    total: int
    r"""Total number of documents returned."""
    took: int
    r"""Elapsed time in milliseconds."""
    docs: List[FetchDocsDocTypedDict]
    is_docs_inline: bool
    r"""Whether the list of documents is included."""
    docs_url: NotRequired[str]
    r"""Download URL for the list of documents."""


class FetchDocsResponse(BaseModel):
    r"""Fetched documents."""

    total: int
    r"""Total number of documents returned."""

    took: int
    r"""Elapsed time in milliseconds."""

    docs: List[FetchDocsDoc]

    is_docs_inline: Annotated[bool, pydantic.Field(alias="isDocsInline")]
    r"""Whether the list of documents is included."""

    docs_url: Annotated[Optional[str], pydantic.Field(alias="docsUrl")] = None
    r"""Download URL for the list of documents."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["docsUrl"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from lambdadb import errors, models, utils
from lambdadb._hooks import HookContext
from lambdadb.types import OptionalNullable, UNSET
from lambdadb.utils import get_security_from_env
from lambdadb.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Dict, List, Mapping, Optional, Union


class Docs(BaseSDK):
    def list_docs(
        self,
        *,
        collection_name: str,
        size: Optional[int] = None,
        page_token: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListDocsResponse:
        r"""List documents in a collection.

        :param collection_name: Collection name.
        :param size: Max number of documents to return at once.
        :param page_token: Next page token.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListDocsRequest(
            collection_name=collection_name,
            size=size,
            page_token=page_token,
        )

        req = self._build_request(
            method="GET",
            path="/collections/{collectionName}/docs",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.ListDocsResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def list_docs_async(
        self,
        *,
        collection_name: str,
        size: Optional[int] = None,
        page_token: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListDocsResponse:
        r"""List documents in a collection.

        :param collection_name: Collection name.
        :param size: Max number of documents to return at once.
        :param page_token: Next page token.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListDocsRequest(
            collection_name=collection_name,
            size=size,
            page_token=page_token,
        )

        req = self._build_request_async(
            method="GET",
            path="/collections/{collectionName}/docs",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.ListDocsResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def upsert(
        self,
        *,
        collection_name: str,
        docs: List[Dict[str, Any]],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.MessageResponse:
        r"""Upsert documents into a collection. Note that the maximum supported payload size is 6MB.

        :param collection_name: Collection name.
        :param docs: A list of documents to upsert.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UpsertDocsRequest(
            collection_name=collection_name,
            request_body=models.UpsertDocsRequestBody(
                docs=docs,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/collections/{collectionName}/docs/upsert",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body, False, False, "json", models.UpsertDocsRequestBody
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="upsertDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "202", "application/json"):
            return unmarshal_json_response(models.MessageResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def upsert_async(
        self,
        *,
        collection_name: str,
        docs: List[Dict[str, Any]],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.MessageResponse:
        r"""Upsert documents into a collection. Note that the maximum supported payload size is 6MB.

        :param collection_name: Collection name.
        :param docs: A list of documents to upsert.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UpsertDocsRequest(
            collection_name=collection_name,
            request_body=models.UpsertDocsRequestBody(
                docs=docs,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/collections/{collectionName}/docs/upsert",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body, False, False, "json", models.UpsertDocsRequestBody
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="upsertDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "202", "application/json"):
            return unmarshal_json_response(models.MessageResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def get_bulk_upsert(
        self,
        *,
        collection_name: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetBulkUpsertDocsResponse:
        r"""Request required info to upload documents.

        :param collection_name: Collection name.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetBulkUpsertDocsRequest(
            collection_name=collection_name,
        )

        req = self._build_request(
            method="GET",
            path="/collections/{collectionName}/docs/bulk-upsert",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getBulkUpsertDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.GetBulkUpsertDocsResponse, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def get_bulk_upsert_async(
        self,
        *,
        collection_name: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetBulkUpsertDocsResponse:
        r"""Request required info to upload documents.

        :param collection_name: Collection name.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetBulkUpsertDocsRequest(
            collection_name=collection_name,
        )

        req = self._build_request_async(
            method="GET",
            path="/collections/{collectionName}/docs/bulk-upsert",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getBulkUpsertDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.GetBulkUpsertDocsResponse, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def bulk_upsert(
        self,
        *,
        collection_name: str,
        object_key: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.MessageResponse:
        r"""Bulk upsert documents into a collection. Note that the maximum supported object size is 200MB.

        :param collection_name: Collection name.
        :param object_key: Object key uploaded based on bulk upsert info.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.BulkUpsertDocsRequest(
            collection_name=collection_name,
            request_body=models.BulkUpsertDocsRequestBody(
                object_key=object_key,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/collections/{collectionName}/docs/bulk-upsert",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body,
                False,
                False,
                "json",
                models.BulkUpsertDocsRequestBody,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="bulkUpsertDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "202", "application/json"):
            return unmarshal_json_response(models.MessageResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def bulk_upsert_async(
        self,
        *,
        collection_name: str,
        object_key: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.MessageResponse:
        r"""Bulk upsert documents into a collection. Note that the maximum supported object size is 200MB.

        :param collection_name: Collection name.
        :param object_key: Object key uploaded based on bulk upsert info.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.BulkUpsertDocsRequest(
            collection_name=collection_name,
            request_body=models.BulkUpsertDocsRequestBody(
                object_key=object_key,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/collections/{collectionName}/docs/bulk-upsert",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body,
                False,
                False,
                "json",
                models.BulkUpsertDocsRequestBody,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="bulkUpsertDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "202", "application/json"):
            return unmarshal_json_response(models.MessageResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def update(
        self,
        *,
        collection_name: str,
        docs: List[Dict[str, Any]],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.MessageResponse:
        r"""Update documents in a collection. Note that the maximum supported payload size is 6MB.

        :param collection_name: Collection name.
        :param docs: A list of documents to update. Each document must contain 'id' field to be updated.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UpdateDocsRequest(
            collection_name=collection_name,
            request_body=models.UpdateDocsRequestBody(
                docs=docs,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/collections/{collectionName}/docs/update",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body, False, False, "json", models.UpdateDocsRequestBody
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="updateDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "202", "application/json"):
            return unmarshal_json_response(models.MessageResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def update_async(
        self,
        *,
        collection_name: str,
        docs: List[Dict[str, Any]],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.MessageResponse:
        r"""Update documents in a collection. Note that the maximum supported payload size is 6MB.

        :param collection_name: Collection name.
        :param docs: A list of documents to update. Each document must contain 'id' field to be updated.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UpdateDocsRequest(
            collection_name=collection_name,
            request_body=models.UpdateDocsRequestBody(
                docs=docs,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/collections/{collectionName}/docs/update",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body, False, False, "json", models.UpdateDocsRequestBody
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="updateDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "202", "application/json"):
            return unmarshal_json_response(models.MessageResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def delete(
        self,
        *,
        collection_name: str,
        ids: Optional[List[str]] = None,
        filter_: Optional[Dict[str, Any]] = None,
        partition_filter: Optional[
            Union[models.PartitionFilter, models.PartitionFilterTypedDict]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.MessageResponse:
        r"""Delete documents by document IDs or query filter from a collection.

        :param collection_name: Collection name.
        :param ids: A list of document IDs.
        :param filter_: Query filter.
        :param partition_filter:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteDocsRequest(
            collection_name=collection_name,
            request_body=models.DeleteDocsRequestBody(
                ids=ids,
                filter_=filter_,
                partition_filter=utils.get_pydantic_model(
                    partition_filter, Optional[models.PartitionFilter]
                ),
            ),
        )

        req = self._build_request(
            method="POST",
            path="/collections/{collectionName}/docs/delete",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body, False, False, "json", models.DeleteDocsRequestBody
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "202", "application/json"):
            return unmarshal_json_response(models.MessageResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def delete_async(
        self,
        *,
        collection_name: str,
        ids: Optional[List[str]] = None,
        filter_: Optional[Dict[str, Any]] = None,
        partition_filter: Optional[
            Union[models.PartitionFilter, models.PartitionFilterTypedDict]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.MessageResponse:
        r"""Delete documents by document IDs or query filter from a collection.

        :param collection_name: Collection name.
        :param ids: A list of document IDs.
        :param filter_: Query filter.
        :param partition_filter:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteDocsRequest(
            collection_name=collection_name,
            request_body=models.DeleteDocsRequestBody(
                ids=ids,
                filter_=filter_,
                partition_filter=utils.get_pydantic_model(
                    partition_filter, Optional[models.PartitionFilter]
                ),
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/collections/{collectionName}/docs/delete",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body, False, False, "json", models.DeleteDocsRequestBody
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "202", "application/json"):
            return unmarshal_json_response(models.MessageResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def fetch(
        self,
        *,
        collection_name: str,
        ids: List[str],
        consistent_read: Optional[bool] = False,
        include_vectors: Optional[bool] = False,
        fields: Optional[
            Union[models.FieldsSelectorUnion, models.FieldsSelectorUnionTypedDict]
        ] = None,
        partition_filter: Optional[
            Union[models.PartitionFilter, models.PartitionFilterTypedDict]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.FetchDocsResponse:
        r"""Lookup and return documents by document IDs from a collection.

        :param collection_name: Collection name.
        :param ids: A list of document IDs to fetch. Note that the maximum number of document IDs is 100.
        :param consistent_read: If your application requires a strongly consistent read, set consistentRead to true. Although a strongly consistent read might take more time than an eventually consistent read, it always returns the last updated value.
        :param include_vectors: If your application need to include vector values in the response, set includeVectors to true.
        :param fields: An object to specify a list of field names to include and/or exclude in the result.
        :param partition_filter:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.FetchDocsRequest(
            collection_name=collection_name,
            request_body=models.FetchDocsRequestBody(
                ids=ids,
                consistent_read=consistent_read,
                include_vectors=include_vectors,
                fields=utils.get_pydantic_model(
                    fields, Optional[models.FieldsSelectorUnion]
                ),
                partition_filter=utils.get_pydantic_model(
                    partition_filter, Optional[models.PartitionFilter]
                ),
            ),
        )

        req = self._build_request(
            method="POST",
            path="/collections/{collectionName}/docs/fetch",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body, False, False, "json", models.FetchDocsRequestBody
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="fetchDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.FetchDocsResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def fetch_async(
        self,
        *,
        collection_name: str,
        ids: List[str],
        consistent_read: Optional[bool] = False,
        include_vectors: Optional[bool] = False,
        fields: Optional[
            Union[models.FieldsSelectorUnion, models.FieldsSelectorUnionTypedDict]
        ] = None,
        partition_filter: Optional[
            Union[models.PartitionFilter, models.PartitionFilterTypedDict]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.FetchDocsResponse:
        r"""Lookup and return documents by document IDs from a collection.

        :param collection_name: Collection name.
        :param ids: A list of document IDs to fetch. Note that the maximum number of document IDs is 100.
        :param consistent_read: If your application requires a strongly consistent read, set consistentRead to true. Although a strongly consistent read might take more time than an eventually consistent read, it always returns the last updated value.
        :param include_vectors: If your application need to include vector values in the response, set includeVectors to true.
        :param fields: An object to specify a list of field names to include and/or exclude in the result.
        :param partition_filter:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.FetchDocsRequest(
            collection_name=collection_name,
            request_body=models.FetchDocsRequestBody(
                ids=ids,
                consistent_read=consistent_read,
                include_vectors=include_vectors,
                fields=utils.get_pydantic_model(
                    fields, Optional[models.FieldsSelectorUnion]
                ),
                partition_filter=utils.get_pydantic_model(
                    partition_filter, Optional[models.PartitionFilter]
                ),
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/collections/{collectionName}/docs/fetch",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body, False, False, "json", models.FetchDocsRequestBody
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="fetchDocs",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.FetchDocsResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from lambdadb.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DataType(str, Enum):
    r"""Partition field data type."""

    KEYWORD = "keyword"


class PartitionConfigTypedDict(TypedDict):
    field_name: NotRequired[str]
    r"""Partition field name."""
    data_type: NotRequired[DataType]
    r"""Partition field data type."""
    num_partitions: NotRequired[int]
    r"""The number of partitions."""


class PartitionConfig(BaseModel):
    field_name: Annotated[Optional[str], pydantic.Field(alias="fieldName")] = None
    r"""Partition field name."""

    data_type: Annotated[Optional[DataType], pydantic.Field(alias="dataType")] = None
    r"""Partition field data type."""

    num_partitions: Annotated[Optional[int], pydantic.Field(alias="numPartitions")] = (
        None
    )
    r"""The number of partitions."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["fieldName", "dataType", "numPartitions"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
